@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '3.37';
+$VERSION = '3.38';
 
 =head1 NAME
 
@@ -78,8 +78,10 @@ sub Reports {
     # get author summary
     my @summary = $dbi->GetQuery('hash','GetDistroSummary',$cgiparams{name});
     unless(@summary) {
-        $dbi->DoQuery('PushDistro',$cgiparams{name});
-        $tvars{update}      = 1;
+        unless($settings{crawler}) {
+            $dbi->DoQuery('PushDistro',$cgiparams{name});
+            $tvars{update} = 1;
+        }
         $tvars{perlvers}    = $cpan->mklist_perls;
         $tvars{osnames}     = $cpan->osnames;
         return;
@@ -88,8 +90,10 @@ sub Reports {
     # if existing page requests, add another to improve rebuild time
     @rows = $dbi->GetQuery('array','GetDistroRequests',$cgiparams{name});
     if(@rows && $rows[0]->[0] > 0) {
-        $dbi->DoQuery('PushDistro',$cgiparams{name});
-        $tvars{update} = 1;
+        unless($settings{crawler}) {
+            $dbi->DoQuery('PushDistro',$cgiparams{name});
+            $tvars{update} = 1;
+        }
     }
 
     # decode from JSON string
